==> bizext.php5.3_5.6.zip: bizext/lib/spout/Common/Type.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPzQ+ngQLXZk9s0fJXHleZgf9TS/KxtVboY5x3ahMd9NWxzhHUv3LfncFikDwsjVP2hWWA9VX
i8p6HNp0RjGx0Fh4Oac3EBv9hZ+6kRs5pvLgwyvpQpRxXqeZN+UpaSU62bqJk1WZ77QBsz0R2thn
4kMe1W3UqvuH81kjOiFUoKAJM2cjNYYB0rBnr0DbqDtUysAmTwmexzd1zYj0/cNXBHqrdCbj8NPF
ttmJwDE2PRMi2pXi6zJ2eHVk3hUkIHHbgG2T5oH2hUinbAIg+whIyIDLTKWpaEli5zkUd2TvxW+Q
ODSofmVFGzJAUWwiqDPMdIpgVH1FY6o9CY/0CbMq7Os+unxrlrTTSvkjWh/lIq8q5UbwZFMggaS2
XiBbl9Cl0KOX5YluyPfjVr0ZVI54XdUvBbL/yjThHMpyPR4nhwNLQcnxjp4CB1aNc06HHRwZucOH
5sat4nbXW+Zh7Th6DUD41e/WAs0WDxBHGrOREvLAy8A122YXbP1Ok2eDl6Wm+G1pOH0Sb3HwBNF8
rSKKX25nLbW/LtROtwLbm19mynXKkrX5AIXkqNhnrCafyJRxX9lobiX5HD61ArtmCb3EtjuoahuB
RnlOuQjbznS50Iw3c1LIMJ8XdHt3+p0MGBGJC9GuSTjWNqHCw0PjGC+SPGJPzfGZ7T5PdMybHHxk
Q0jnlklFo2Tb6badSENDyJI8GbjeE/mORFI8VsSArEIN6qfGVf23HgWjSLst

==> bizext.php7.0.zip: bizext/lib/spout/Common/Type.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPnsTlv3hPGIdHYWgiraxX9nniWR9WxfRZVALDz+/77/3yDWK3ga2CYxZuIqmjkM5i6Rt9iSO
wdtfYLGZmy6R6oRmPkOq36Lv46ulUIhNDWEzSjRXYAzLEvYhb42cUNPqRbxX0JPLyoMxUy1nDNXR
seb3y85414m8pzTbY2zx/hqGJH+QgArHWzith4uz/PiraDuFleckvxUqDoViPo1xbT6ylJU4R6lg
YAxX94AiCdYbTbvSMkwT7SWKkageXM+z6nekjrQHVlkUQNpgSQZVMJygHAvZiasOrM5bMUw+hA3/
1JqVmO5NLSt6VUstKTWmt6XhtUhoCr+SbpNvTs6dH/w5mRzs2HLdEoNBy4zt2UHJfCLzaawJwG58
4fY4KXg2Up0/6Ge61/j2aKbYD2nmJ/OBWkC3784A3lyNuZ8fitiCAsvIlvqXIjkXf2e/PoxNe0fW
wcm7hnZ8OJEQlYCxu0OGAZ8hMDFHhnLAG18h+1h2lCXp3YMgCs3VxigCoGXR1xOobQna3fPhxwQ0
RMCzkE/Ig5gLdaAyuocgQTEgPduzu05/YoqWVTG7fAd9nfvHgDM6TipLDm0BybLgWfJTH+KQbvVd
QceGRDFwa6GaGI1cR/A18kzean5nGRt9zFRkORjREtfAsBreIDKcI384jOkd3AVgp6PfBNMXvsTn
0XV6Hwi+XlbrZHCSfOJasDVcD1Ghjz0uofRuTSRe5j83cSi0yo6MHvftqY17AyAsbbJRd5snpwQC
xrOneBF3svrCVhRRLUIGDjvNXCqweOUd7ER/xAjLRdI1FpS7AEErNhkd2pOxuHKXC50zjuG8yyQF
0edVQjNP4v7orlaNacg6uQfcX4i6cDW4QQSQ/zmJKLGVlVwYKTLHJhCMyy+7yN24NYJKJuPcmX02
KZEdbujYRR+Ens+S6QGeY576YkPRKXPfKUT6ktRim19o2EQySVGbjDAbh+G1ASPr9WgjwizLQG==
